@@ -473,11 +473,11 @@ for(;x < argc; x++)
     if(argv[x + 1])
     {
       if(strpbrk(argv[x +1], "vV"))
-        ex_in.READ_IT = 2;
+        ex_in.READ_IT = 2; /* verbose */
       else if(strpbrk(argv[x +1], "sS"))
-        ex_in.READ_IT = 1;
+        ex_in.READ_IT = 1;/* short */
       else if(strpbrk(argv[x +1], "tT"))
-        ex_in.READ_IT = 0;
+        ex_in.READ_IT = 0; /* turn off snooping*/
     }
     x++;
     break;
